@@ -473,8 +473,11 @@ class FinishInAppliance(Appliance):
         program_fingerprint = self._program_fingerprint()
         if len(self.program_selected) > 0 and self._program_finish_in_relative_sec > 0 and self.state == self.STATE_READY:
             if self._durations.get(program_fingerprint, -1) != self._program_finish_in_relative_sec:   # duration changed?
-                self._durations.put(program_fingerprint, self._program_finish_in_relative_sec)
-                logging.info("duration update for " + program_fingerprint + " with " + str(self._program_finish_in_relative_sec))
+                if self._program_finish_in_relative_sec < 5 * 60 * 60:
+                    self._durations.put(program_fingerprint, self._program_finish_in_relative_sec)
+                    logging.info("duration update for " + program_fingerprint + " with " + str(self._program_finish_in_relative_sec))
+                else:
+                    logging.info("duration update for " + program_fingerprint + " with " + str(self._program_finish_in_relative_sec) + " ignored. Value seems to high")
 
         # get duration
         duration_sec = self._durations.get(program_fingerprint, None)
@@ -505,7 +508,7 @@ class FinishInAppliance(Appliance):
         if self.state == self.STATE_STARTABLE:
             program_duration_sec = self.__program_duration_sec()
             remaining_secs_to_finish = self.__compute_remaining_secs_to_finish(start_date, program_duration_sec)
-
+            logging.info("remaining seconds to finished " + str(remaining_secs_to_finish) + " (" + print_duration(remaining_secs_to_finish) + ") computed for " + self.name + " with program " + self.program_selected + " (end date " + (datetime.fromisoformat(start_date) + timedelta(seconds=program_duration_sec)).strftime("%Y-%m-%dT%H:%M") + " = start date " + start_date + " + " + print_duration(program_duration_sec) + " program duration)")
             try:
                 data = {
                     "data": {
@@ -651,7 +654,7 @@ class Dryer(FinishInAppliance):
     @property
     def program_drying_target_adjustment(self) -> str:
         if len(self.__program_drying_target_adjustment) > 0:
-            return self.__program_drying_.starget_adjustment[self.__program_drying_target_adjustment.rindex('.') + 1:]
+            return self.__program_drying_target_adjustment[self.__program_drying_target_adjustment.rindex('.') + 1:]
         else:
             return ""
 
